package main

import (
	"fmt"
	"io"
	"net/http"
	"os"
	"strings"
	"time"
)

func die(format string, a ...any) {
	if !strings.HasSuffix(format, "\n") {
		format += "\n"
	}
	fmt.Fprintf(os.Stderr, format, a...)
	os.Exit(1)
}

func main() {
	if len(os.Args) != 2 {
		die("Usage: %s URL", os.Args[0])
	}
	// url can be http or https
	url := os.Args[1]

	client := &http.Client{
		Timeout: 5 * time.Second,
	}

	req, err := http.NewRequest(http.MethodGet, url, nil)
	if err != nil {
		die("error: %v", err)
	}
	req.Header.Add("X-My-Client", "CSCI780")

	resp, err := client.Do(req)
	if err != nil {
		die("error: %v", err)
	}
	defer resp.Body.Close()

	fmt.Printf("status code: %d\n", resp.StatusCode)
	fmt.Printf("status: %s\n", resp.Status)
	fmt.Printf("protocol: %s\n", resp.Proto)
	for k, v := range resp.Header {
		fmt.Printf("%s: %s\n", k, strings.Join(v, ","))
	}
	fmt.Println("======================")
	io.Copy(os.Stdout, resp.Body)
}
